@@ -150,7 +150,6 @@ Widget::Init (CallbackBin *events)
 		  return -1;
 		}
 		this->appShell = appShell.get();
-		NS_ADDREF(this->appShell);
 		this->appShell->Create(0, nsnull);
 		this->appShell->Spinup();
 #endif
@@ -162,7 +161,7 @@ Widget::Init (CallbackBin *events)
 }
 
 nsresult 
-Widget::Create (Handle *hwnd, PRUint32 width, PRUint32 height)
+Widget::Bind (Handle *hwnd, PRUint32 width, PRUint32 height)
 {
 	this->width = width;
 	this->height = height;
@@ -188,6 +187,11 @@ Widget::Create (Handle *hwnd, PRUint32 width, PRUint32 height)
 	browserWindow->AddRef ();
 	browserWindow->SetChromeFlags( nsIWebBrowserChrome::CHROME_ALL );
 
+	return NS_OK;
+}
+nsresult 
+Widget::Create ()
+{
 	this->CreateBrowserWindow ();
 	return NS_OK;	
 }
@@ -195,6 +199,7 @@ Widget::Create (Handle *hwnd, PRUint32 width, PRUint32 height)
 void
 Widget::Shutdown ()
 {
+	browserWindow->Shutdown ();
 	widgetCount--;
 
 	if (widgetCount == 0) {
@@ -202,15 +207,14 @@ Widget::Shutdown ()
 		if (appShell) {
 			// Shutdown the appshell service.
 			this->appShell->Spindown();
-			NS_RELEASE(this->appShell);
 			this->appShell = 0;
 		}
 #endif
-#if XUL_VERSION > 2
-		XPCOMGlueShutdown ();
-#else
-		GRE_Shutdown();
+
+#if XUL_VERSION == 2
+		GRE_Shutdown ();
 #endif
+		XPCOMGlueShutdown ();
 	}
 }
 
@@ -225,7 +229,6 @@ Widget::CreateBrowserWindow()
 		return -1;
 	}
 	Handle * nativeMozWindow = browserWindow->getNativeWin ();
-	this->Navigate ("about:blank");
 	return NS_OK;
 }
 
@@ -429,7 +432,7 @@ Widget::GetProxyForNavigation ()
 	return GetProxyForObject (nsIWebNavigation::GetIID(), navigation, getter_AddRefs (this->webNav));
 }
 
-char *
+PRUnichar *
 Widget::EvalScript (const char * script)
 {
 	nsCOMPtr< nsIScriptGlobalObjectOwner > theGlobalObjectOwner( do_GetInterface( browserWindow->webBrowser ) );
@@ -443,7 +446,7 @@ Widget::EvalScript (const char * script)
 	nsresult result = theScriptContext->EvaluateString (NS_ConvertUTF8toUTF16(script),
 	   nsnull, nsnull, "", 1, nsnull, &output, &IsUndefined);
 
-	return (char *)NS_ConvertUTF16toUTF8 (output).get ();
+	return (PRUnichar *)NS_StringCloneData (output);
 }
 
 // EVENTS
