@@ -45,6 +45,7 @@ class Widget
 
 			// initialization and shutdown
 			delegates["init"].bind (this, &Widget::Init);
+			delegates["bind"].bind (this, &Widget::Bind);
 			delegates["create"].bind (this, &Widget::Create);
 			delegates["shutdown"].bind (this, &Widget::Shutdown);
 
@@ -67,6 +68,7 @@ class Widget
 			delegates["getNavigation"].bind (this, &Widget::GetNavigation);
 			delegates["getProxyForObject"].bind (this, &Widget::GetProxyForObject);
 			delegates["evalScript"].bind (this, &Widget::EvalScript);
+			delegates["getServiceManager"].bind (this, &Widget::GetServiceManager);
 		}
 		~Widget() {
 			int a = 0;
@@ -85,8 +87,12 @@ class Widget
 			return this->Init (params->events);
 		}
 
+		nsresult Bind (Params * params) {
+			return this->Bind (params->hwnd, params->width, params->height);
+		}
+
 		nsresult Create (Params * params) {
-			return this->Create (params->hwnd, params->width, params->height);
+			return this->Create ();
 		}
 
 		nsresult Shutdown (Params * params) {
@@ -153,17 +159,28 @@ class Widget
 		}
 		
 		nsresult EvalScript (Params * params) {
-			params->string = this->EvalScript (params->string);
+			params->uniString = this->EvalScript (params->string);
 			return 0;
 		}
 
+		
+		nsresult GetServiceManager (Params * params) {
+			nsCOMPtr<nsIServiceManager> result;
+			nsCOMPtr<nsIServiceManager> servMan;
+			NS_GetServiceManager (getter_AddRefs (servMan));
+			this->GetProxyForObject (nsIServiceManager::GetIID(), servMan, getter_AddRefs (result));
+			NS_ADDREF(params->result = result);
+			return NS_OK;
+		}
+		
 		// end of generic targets for delegation
 
 		// Initialization and Shutdown
 		nsresult Init (CallbackBin * events);
 		void Shutdown ();
-		nsresult Create (Handle * hwnd, PRUint32 width, PRUint32 height);
-		nsresult CreateBrowserWindow ();
+		nsresult Bind (Handle *hwnd, PRUint32 width, PRUint32 height);
+		nsresult Create ();
+		nsresult CreateBrowserWindow();
 
 		// Layout
 		nsresult Focus (FocusOption focus);
@@ -186,7 +203,7 @@ class Widget
 		nsresult GetProxyForNavigation ();
 		nsresult GetProxyForObject (REFNSIID iid, nsISupports *object, void **result);
 		
-		char * EvalScript (const char * script);
+		PRUnichar * EvalScript (const char * script);
 
 		Handle * getHandle () { return this->hwnd;}
 
@@ -228,6 +245,6 @@ class Widget
 		Platform platform;
 	
 		// the appshell we have created
-		nsIAppShell *appShell;
+		nsCOMPtr<nsIAppShell> appShell;
 };
 #endif
