@@ -46,10 +46,10 @@ gluezilla_init (Platform platform, Platform * mozPlatform)
 }
 
 NS_METHOD_(Handle*)
-gluezilla_createBrowserWindow (CallbackBin *events, Handle *hwnd, 
-							   PRInt32 width, PRInt32 height, 
-							   const char * startDir, const char * dataDir, 
-							   Platform platform)
+gluezilla_bind (CallbackBin *events, Handle *hwnd, 
+			    PRInt32 width, PRInt32 height, 
+			    const char * startDir, const char * dataDir, 
+			    Platform platform)
 {
 	Widget *widget = new Widget (strdup(startDir), strdup(dataDir), platform);
 	
@@ -68,7 +68,7 @@ gluezilla_createBrowserWindow (CallbackBin *events, Handle *hwnd,
 	Handle * handle = hwnd;
 
 	p = new Params ();
-	p->name = "create";
+	p->name = "bind";
 	p->instance = widget;
 	p->hwnd = hwnd;
 	p->width = width;
@@ -84,6 +84,20 @@ gluezilla_createBrowserWindow (CallbackBin *events, Handle *hwnd,
 	return reinterpret_cast<Handle*>(widget);
 }
 
+NS_METHOD_(int) gluezilla_createBrowserWindow (Handle *instance)
+{
+	Widget *widget = reinterpret_cast<Widget *> (instance);
+
+	Params * p = new Params ();
+	p->name = "create";
+	p->instance = widget;
+
+	nsresult result = widget->BeginInvoke (p);
+	if (p)
+		delete (p);
+	return result;
+}
+
 /*******************
 Layout
 *******************/
@@ -355,6 +369,22 @@ gluezilla_getServiceManager()
 	return servMan;
 }
 
+NS_METHOD_(nsIServiceManager*)
+gluezilla_getServiceManager2 (Handle *instance)
+{
+	Widget *widget = reinterpret_cast<Widget *> (instance);
+	Params * p = new Params ();
+	p->name = "getServiceManager";
+	p->instance = widget;
+	nsresult rv = widget->BeginInvoke (p);
+	nsIServiceManager * ret (reinterpret_cast<nsIServiceManager *> (p->result));
+	NS_ADDREF(ret);
+	if (p)
+		delete (p);
+	
+	return ret;
+}
+
 NS_METHOD_(void)
 gluezilla_getProxyForObject (Handle *instance, REFNSIID iid, nsISupports *object, nsISupports ** result)
 {
@@ -425,7 +455,7 @@ gluezilla_CStringSetData (nsACString &aStr, const char *aBuf, PRUint32 aCount)
 	return NS_CStringSetData (aStr, aBuf, aCount);
 }
 
-NS_METHOD_(char *)
+NS_METHOD_(PRUnichar *)
 gluezilla_evalScript (Handle *instance, const char * script)
 {
 	Widget *widget = reinterpret_cast<Widget *> (instance);	
@@ -435,7 +465,7 @@ gluezilla_evalScript (Handle *instance, const char * script)
 	p->string = strdup (script);
 
 	nsresult result = widget->BeginInvoke (p);
-	char * string = strdup (p->string);
+	PRUnichar * string = p->uniString;
 	if (p)
 		delete (p);
 	return string;
